/* $Id$
 *
 * GNOME Internet Radio Locator
 *
 * Copyright (C) 2017-2019  Aamot Software
 *
 * Author: Ole Aamot <ole@gnome.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef GNOME_INTERNET_RADIO_LOCATOR_RADIUS_H
#define GNOME_INTERNET_RADIO_LOCATOR_RADIUS_H

void gnome_internet_radio_locator_radius (float latitude, float longitude, int radius);

#endif /* GNOME_INTERNET_RADIO_LOCATOR_RADIUS_H */
